==> claromentis-framework-9.6.6-26891208.zip: web/intranet/core/classes/Http/TemplaterCallResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d6653e8a0ab784" . "8e536215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array("_6aead4bff5639b251a" . "ebcf8a630e43a7" => base64_decode("aW5m" . "bw=="));








class TemplaterCallResponse
{
    public $template;
    public $args;
    public $page_title;
    public $datasources;
    public $message;
    public $is_error_message;
    public $http_status = 200;
    public $http_headers = [];
    public function __construct($template, array $args, $_678d945258a520c3df1c42fe4b558f34 = '')
    {
        $this->template = $template;
        $this->args = $args;
        $this->page_title = $_678d945258a520c3df1c42fe4b558f34;
        $this->datasources = array();
    }
    public function SetDatasrc(array $_2142cfafde78da7f579e7923dee6f777)
    {
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
    }
    public function SetMessage($_e05e0022a2e5ad344b9c4a0d3f64e1a5, $_8df4fa2d5c8d8c2e6de4577a36506bb1 = false)
    {
        $this->message = (string) $_e05e0022a2e5ad344b9c4a0d3f64e1a5;
        if ($_8df4fa2d5c8d8c2e6de4577a36506bb1 === $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_6aead4bff5639b251aebcf8a630e43a" . "7"]) {
            $this->is_error_message = $GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"]["_6aead4bff5639b251aebcf" . "8a630e43a7"];
        } else {
            $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1 ? 1 : 0;
        }
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/core/classes/Http/TemplaterCallResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] ?: array()) + array("_6aead4bf" . "f5639b251" . "aebcf8a63" . "0e43a7" => base64_decode("aW5mbw=" . "="));








class TemplaterCallResponse
{
    public $template;
    public $args;
    public $page_title;
    public $datasources;
    public $message;
    public $is_error_message;
    public $http_status = 200;
    public $http_headers = [];
    public function __construct($template, array $args, $_678d945258a520c3df1c42fe4b558f34 = '')
    {
        $this->template = $template;
        $this->args = $args;
        $this->page_title = $_678d945258a520c3df1c42fe4b558f34;
        $this->datasources = array();
    }
    public function SetDatasrc(array $_2142cfafde78da7f579e7923dee6f777)
    {
        $this->datasources = $_2142cfafde78da7f579e7923dee6f777;
    }
    public function SetMessage($_e05e0022a2e5ad344b9c4a0d3f64e1a5, $_8df4fa2d5c8d8c2e6de4577a36506bb1 = false)
    {
        $this->message = (string) $_e05e0022a2e5ad344b9c4a0d3f64e1a5;
        if ($_8df4fa2d5c8d8c2e6de4577a36506bb1 === $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_6aead4bf" . "f5639b251" . "aebcf8a63" . "0e43a7"]) {
            $this->is_error_message = $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_6aead4bff5639b251aebcf8a" . "630e43a7"];
        } else {
            $this->is_error_message = $_8df4fa2d5c8d8c2e6de4577a36506bb1 ? 1 : 0;
        }
    }
}
